import * as L from 'leaflet';

interface LassoHandlerOptions {
    polygon?: L.PolylineOptions;
    intersect?: boolean;
}
interface LassoHandlerFinishedEventData {
    originalEvent: MouseEvent;
    latLngs: L.LatLng[];
    layers: L.Layer[];
}
declare type LassoHandlerFinishedEvent = L.LeafletEvent & LassoHandlerFinishedEventData;
declare const ENABLED_EVENT = "lasso.enabled";
declare const DISABLED_EVENT = "lasso.disabled";
declare const FINISHED_EVENT = "lasso.finished";
declare const ACTIVE_CLASS = "leaflet-lasso-active";
declare class LassoHandler extends L.Handler {
    options: LassoHandlerOptions;
    private map;
    private polygon?;
    private onMapMouseDownBound;
    private onDocumentMouseMoveBound;
    private onDocumentMouseUpBound;
    constructor(map: L.Map, options?: LassoHandlerOptions);
    setOptions(options: LassoHandlerOptions): void;
    toggle(): void;
    addHooks(): void;
    removeHooks(): void;
    private onMapMouseDown;
    private onDocumentMouseMove;
    private onDocumentMouseUp;
    private eventToMouseEvent;
    private finish;
}

interface LassoControlOptionsData {
    title?: string;
}
declare type LassoControlOptions = L.ControlOptions & LassoControlOptionsData & LassoHandlerOptions;
declare class LassoControl extends L.Control {
    options: LassoControlOptions;
    private lasso?;
    constructor(options?: LassoControlOptions);
    setOptions(options: LassoControlOptions): void;
    onAdd(map: L.Map): HTMLDivElement;
    enabled(): boolean;
    enable(): void;
    disable(): void;
    toggle(): void;
}

declare module 'leaflet' {
    type Lasso = LassoHandler;
    let Lasso: typeof LassoHandler;
    let lasso: (...args: ConstructorParameters<typeof LassoHandler>) => LassoHandler;
    namespace Control {
        type Lasso = LassoControl;
        let Lasso: typeof LassoControl;
    }
    namespace control {
        let lasso: (...args: ConstructorParameters<typeof LassoControl>) => LassoControl;
    }
}

export { ACTIVE_CLASS, DISABLED_EVENT, ENABLED_EVENT, FINISHED_EVENT, LassoControl, LassoControlOptions, LassoControlOptionsData, LassoHandler, LassoHandlerFinishedEvent, LassoHandlerOptions };
